.. Copyright (C) 2015-2019 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`memcached`__ is a cache daemon which keeps its data in RAM. It can be used by
other applications to speed up slow operations on the databases/data stores.

.. __: https://memcached.org/
